#! /usr/bin/env python
# vim: set fileencoding=utf-8 :
# Copyright (C) 2015, Christopher Swingley <cswingle@swingleydev.com>
# Licensed under the terms of a Creative Commons
# Attribution-ShareAlike 4.0 International License
from __future__ import print_function
from __future__ import unicode_literals
usage = """Parse the speedtest simple results into a table
"""
import argparse
import sys
import datetime
import re

parser = argparse.ArgumentParser(description=usage,
                                 formatter_class=argparse.
                                 RawDescriptionHelpFormatter)
group = parser.add_mutually_exclusive_group()
group.add_argument("-v", "--verbose", action="store_true", dest="verbose",
                   default=True, help="be more verbose")
group.add_argument("-q", "--quiet", action="store_false", dest="verbose",
                   default=True, help="be quiet")

parser.add_argument("infile", type=argparse.FileType('r'))
parser.add_argument("outfile", nargs="?", type=argparse.FileType('w'),
                    default=sys.stdout)

args = parser.parse_args()


def get_key_value(kv):
    """ Get the number out of a key-value line """
    key = kv.split(':')[0].strip()
    value = kv.split(':')[1].strip().split()[0].strip()
    return (key, value)

date_regex = re.compile('^(Sun|Mon|Tue|Wed|Thu|Fri|Sat)')
kv_regex = re.compile('^(Ping|Download|Upload):')
date = ping = download = upload = None
print("date,ping,download,upload", file=args.outfile)
while True:
    try:
        string = next(args.infile).strip()
    except StopIteration:
        break
    else:
        if date_regex.match(string):
            if download is not None:
                print(("{date:%Y-%m-%d %H:%M:%S},"
                       "{ping},"
                       "{download},"
                       "{upload}").format(date=date,
                                          ping=ping,
                                          download=download,
                                          upload=upload),
                      file=args.outfile)
            date_str = re.sub('(AKST|AKDT) ', '', string)
            date = datetime.datetime.strptime(date_str, "%a %b %d %H:%M:%S %Y")
            ping = download = upload = None
        if kv_regex.match(string):
            (key, value) = get_key_value(string)
            if key == 'Ping':
                ping = value
            elif key == 'Download':
                download = value
            elif key == 'Upload':
                upload = value
